==> scadat-0.4.0-py2-none-any.whl: scadat-0.4.0.data/scripts/scadat_search.sh <==
#!/bin/sh
#   author:martinmhan@yahoo.com date:  22/04/2014
#   scadat is a bash command line interface to the tango scada
#   Copyright (C) <2014>  <Martin Mohan>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software Foundation,
#   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA

if [ $# -ne 2 ];then 
    printf "%s\n" "Usage: $0 ipbase nr_values"
    printf "e.g. %s\n" "$0 198.23.242.110 5"
#    printf "e.g. %s\n" "$0 23.239.140.191 5"
    exit
fi

ip=$1
ipbase="$(echo $ip | cut -d. -f1-3)"
ip_start="$(echo $ip | cut -d. -f4)"
ip_end=$(($ip_start+$2))
ip_end=$((ip_end-1))
iprange="$ip_start $ip_end"

#printf "%s\n" "$0 ip: $ip ipbase: $ipbase iprange: $iprange"
for i in `seq $iprange`; 
    do nc -nz -w1 $ipbase.$i 10000; 
        if [ $? -eq 0 ];then 
            printf "%s\n" "nc -nvz -w1 $ipbase.$i 10000 - open"
            export TANGO_HOST=$ipbase.$i:10000
            scadat -v > /dev/null
            if [ $? -eq 0 ];then 
                printf "%s\n" "scadat -v - pass (export TANGO_HOST=$ipbase.$i:10000)"
            else
                printf "%s\n" "scadat -v - fail (export TANGO_HOST=$ipbase.$i:10000)"
            fi
        else
            printf "%s\n" "nc -nvz -w1 $ipbase.$i 10000 - closed"
        fi
    done

==> scadat-0.4.1-py2-none-any.whl: scadat-0.4.1.data/scripts/scadat_search.sh <==
#!/bin/sh
#   author:martinmhan@yahoo.com date:  22/04/2014
#   scadat is a bash command line interface to the tango scada
#   Copyright (C) <2014>  <Martin Mohan>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software Foundation,
#   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA

if [ $# -ne 2 ];then 
    printf "%s\n" "Usage: $0 ipbase nr_values"
    printf "e.g. %s\n" "$0 198.23.242.110 5"
#    printf "e.g. %s\n" "$0 23.239.140.191 5"
    exit
fi

ip=$1
ipbase="$(echo $ip | cut -d. -f1-3)"
ip_start="$(echo $ip | cut -d. -f4)"
ip_end=$(($ip_start+$2))
ip_end=$((ip_end-1))
iprange="$ip_start $ip_end"

#printf "%s\n" "$0 ip: $ip ipbase: $ipbase iprange: $iprange"
for i in `seq $iprange`; 
    do nc -nz -w1 $ipbase.$i 10000; 
        if [ $? -eq 0 ];then 
            printf "%s\n" "nc -nvz -w1 $ipbase.$i 10000 - open"
            export TANGO_HOST=$ipbase.$i:10000
            scadat -v > /dev/null 2>&1
            if [ $? -eq 0 ];then 
                printf "%s\n" "scadat -v - pass (export TANGO_HOST=$ipbase.$i:10000)"
            else
                printf "%s\n" "scadat -v - fail (export TANGO_HOST=$ipbase.$i:10000)"
            fi
        else
            printf "%s\n" "nc -nvz -w1 $ipbase.$i 10000 - closed"
        fi
    done
